@@ -45,6 +45,7 @@ sub _build {
       }
     }
   }
+
   # else {
   #   push @{ $q->{args} }, undef;
   # }
@@ -412,16 +413,16 @@ sub sample {
 # AGGREGATION
 
 sub group {
-  my $self = shift;
-  my $args = [@_];
+  my $self    = shift;
+  my $args    = [@_];
   my $optargs = {};
 
   if ( ref $args->[ $#{$args} ] eq 'HASH' ) {
     $optargs = pop @{$args};
   }
 
-  if( ref $args->[0] && ref $args->[0] ne 'CODE' ) {
-    $args = Rethinkdb::Util->_wrap_func($args->[0]);
+  if ( ref $args->[0] && ref $args->[0] ne 'CODE' ) {
+    $args = Rethinkdb::Util->_wrap_func( $args->[0] );
   }
 
   my $q = Rethinkdb::Query->new(
@@ -458,6 +459,29 @@ sub reduce {
   return $q;
 }
 
+sub fold {
+  my $self    = shift;
+  my $acc     = shift;
+  my $fn      = shift;
+  my $emitter = shift;
+
+  my $args = [$acc, $fn];
+  my $optargs = {};
+
+  if($emitter) {
+    $optargs = { emit => $emitter };
+  }
+
+  my $q = Rethinkdb::Query->new(
+    _parent => $self,
+    _type   => $self->_termType->fold,
+    args    => $args,
+    optargs => $optargs
+  );
+
+  return $q;
+}
+
 sub count {
   my $self = shift;
   my $args = shift;
@@ -564,7 +588,7 @@ sub pluck {
 
 sub without {
   my $self = shift;
-  my $args = @_ ? @_ > 1 ? [@_] : [ @{ $_[0] } ] : [];
+  my $args = [@_];
 
   my $q = Rethinkdb::Query->new(
     _parent => $self,
@@ -793,6 +817,19 @@ sub keys {
   return $q;
 }
 
+sub values {
+  my $self = shift;
+  my $args = [@_];
+
+  my $q = Rethinkdb::Query->new(
+    _parent => $self,
+    _type   => $self->_termType->values,
+    args    => $args,
+  );
+
+  return $q;
+}
+
 # STRING MANIPULATION
 
 sub match {
@@ -1638,6 +1675,32 @@ if you want to e.g. order the groups by the value of their reduction.
 Produce a single value from a sequence through repeated application of a
 reduction function.
 
+=head2 fold
+
+  r->table('words')->order_by('id')->fold(
+    '',
+    sub ($$) {
+      my ( $acc, $word ) = @_;
+      return $acc->add( r->branch( $acc->eq(''), '', ', ' )->add($word) );
+    }
+  )->run;
+
+  r->table('tracker')->filter( { name => 'bob' } )->order_by('date')
+    ->bracket('weight')->fold(
+    [],
+    sub ($$) {
+      my ( $acc, $row ) = @_;
+      return $acc->append($row)->limit(5);
+    },
+    sub ($$$) {
+      my ( $acc, $row, $new_acc ) = @_;
+      return r->branch( new_acc->size()->eq(5), [ new_acc->avg() ], [] );
+    }
+    )->run;
+
+Apply a function to a sequence in order, maintaining state via an accumulator.
+The fold command returns either a single value or a new sequence.
+
 =head2 count
 
   r->table('marvel')->count->add(r->table('dc')->count->run
@@ -1844,6 +1907,13 @@ Change a value in an array at a given index. Returns the modified array.
 
 Return an array containing all of the object's keys.
 
+=head2 values
+
+  r->table('marvel')->get('ironman')->values->run;
+
+Return an array containing all of an object’s values. C<values> guarantees the
+values will come out in the same order as L<keys>.
+
 =head2 match
 
   r->table('users')->filter(sub {
